@@ -31,7 +31,7 @@ ISOBaseDate <- R6Class("ISOBaseDate",
    ),
    public = list(
      value = NA,
-     initialize = function(xml = NULL, value){
+     initialize = function(xml = NULL, value = NULL){
        super$initialize(xml = xml)
        if(is.null(xml)){
          if(all(class(value)==c("POSIXct","POSIXt"))){
