@@ -7,12 +7,10 @@
 #' @return Object of \code{\link{R6Class}} for modelling an ISO Role
 #' @format \code{\link{R6Class}} object.
 #'
-#' @field value
-#'
 #' @section Methods:
 #' \describe{
 #'  \item{\code{new(xml,value)}}{
-#'    This method is used to instantiate an ISORole
+#'    This method is used to instantiate an \code{\link{ISORole}}
 #'  }
 #' }
 #' 
@@ -35,7 +33,7 @@ ISORole <- R6Class("ISORole",
     xmlNamespacePrefix = "GMD"
   ),
   public = list(
-    initialize = function(xml = NULL, value){
+    initialize = function(xml = NULL, value = NULL){
       super$initialize(xml = xml, id = private$xmlElement, value = value, setValue = TRUE)
     }
   )                        
