@@ -10,6 +10,8 @@ require(XML)
 context("GMLElement")
 
 test_that("GML Element",{
+  testthat::skip_on_cran()
+  testthat::skip_on_travis()
   
   #encoding
   gml1 <- GMLElement$new(element = "tag1")
