@@ -54,9 +54,9 @@ test_that("encoding",{
   ct$addDate(d)
   ct$setEdition("1.0")
   ct$setEditionDate(ISOdate(2015,1,1))
-  ct$setIdentifier(ISOMetaIdentifier$new(code = "identifier"))
-  ct$setPresentationForm("mapDigital")
-  ct$setCitedResponsibleParty(rp)
+  ct$addIdentifier(ISOMetaIdentifier$new(code = "identifier"))
+  ct$addPresentationForm("mapDigital")
+  ct$addCitedResponsibleParty(rp)
   md$setCitation(ct)
   
   #graphic overview
@@ -307,9 +307,9 @@ test_that("encoding - i18n",{
   ct$addDate(d)
   ct$setEdition("1.0")
   ct$setEditionDate(ISOdate(2015,1,1))
-  ct$setIdentifier(ISOMetaIdentifier$new(code = "identifier"))
-  ct$setPresentationForm("mapDigital")
-  ct$setCitedResponsibleParty(rp)
+  ct$addIdentifier(ISOMetaIdentifier$new(code = "identifier"))
+  ct$addPresentationForm("mapDigital")
+  ct$addCitedResponsibleParty(rp)
   md$setCitation(ct)
   
   #graphic overview
