@@ -9,7 +9,8 @@ require(testthat)
 context("ISOGeographicBoundingBox")
 
 test_that("encoding",{
-  
+  testthat::skip_on_cran()
+  testthat::skip_on_travis()
   #encoding
   md <- ISOGeographicBoundingBox$new(minx = -180, miny = -90, maxx = 180, maxy = 90)
   xml <- md$encode()
