@@ -9,7 +9,8 @@ require(testthat)
 context("ISORecordType")
 
 test_that("encoding",{
-  
+  testthat::skip_on_cran()
+  testthat::skip_on_travis()
   #encoding
   md <- ISORecordType$new(value = "myvalue")
   expect_is(md, "ISORecordType")
