@@ -9,7 +9,8 @@ require(testthat)
 context("ISOVerticalExtent")
 
 test_that("encoding",{
-  
+  testthat::skip_on_cran()
+  testthat::skip_on_travis()
   #encoding
   ve <- ISOVerticalExtent$new()
   ve$setMinimumValue(0)
